==> tuia-ecb-center-api-1.1.1.63-20211025.144534-3-sources.jar: cn/com/duiba/tuia/ecb/center/draw/dto/v2/UserPlayBaseDTO.java <==
package cn.com.duiba.tuia.ecb.center.draw.dto.v2;

import java.io.Serializable;
import java.util.List;

/**
 * @ClassName UserPlayTimesDTO
 * @Description
 * @Author Zaizai
 * @Date 2021/3/4 3:56 下午
 **/
public class UserPlayBaseDTO implements Serializable {

    private static final long serialVersionUID = -9019298654748924786L;

    /**
     * 用户id
     */
    protected Long baseUserId;

    /**
     * 活动id
     */
    protected Long activityId;

    /**
     * 媒体id
     */
    protected Long appId;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * 推啊用户id
     */
    private Long consumerId;

    /**
     * 参与次数
     */
    protected Integer joinTimes;

    /**
     * 触发额外次数的次数
     */
    protected Integer touchExtTimes;

    /**
     * 已获得奖励
     */
    protected Integer obtainedAwardInfo;

    /**
     * 额外信息
     */
    protected DrawExtInfoDTO extInfo;

    public Long getBaseUserId() {
        return baseUserId;
    }

    public void setBaseUserId(Long baseUserId) {
        this.baseUserId = baseUserId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getJoinTimes() {
        return joinTimes;
    }

    public void setJoinTimes(Integer joinTimes) {
        this.joinTimes = joinTimes;
    }

    public Integer getTouchExtTimes() {
        return touchExtTimes;
    }

    public void setTouchExtTimes(Integer touchExtTimes) {
        this.touchExtTimes = touchExtTimes;
    }

    public Integer getObtainedAwardInfo() {
        return obtainedAwardInfo;
    }

    public void setObtainedAwardInfo(Integer obtainedAwardInfo) {
        this.obtainedAwardInfo = obtainedAwardInfo;
    }

    public DrawExtInfoDTO getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(DrawExtInfoDTO extInfo) {
        this.extInfo = extInfo;
    }

}

==> tuia-ecb-center-api-1.1.1.68-sources.jar: cn/com/duiba/tuia/ecb/center/draw/dto/v2/UserPlayBaseDTO.java <==
package cn.com.duiba.tuia.ecb.center.draw.dto.v2;

import java.io.Serializable;
import java.util.List;

/**
 * @ClassName UserPlayTimesDTO
 * @Description
 * @Author Zaizai
 * @Date 2021/3/4 3:56 下午
 **/
public class UserPlayBaseDTO implements Serializable {

    private static final long serialVersionUID = -9019298654748924786L;

    /**
     * 用户id
     */
    protected Long baseUserId;

    /**
     * 活动id
     */
    protected Long activityId;

    /**
     * 媒体id
     */
    protected Long appId;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * 推啊用户id
     */
    private Long consumerId;

    /**
     * 参与次数
     */
    protected Integer joinTimes;

    /**
     * 触发额外次数的次数
     */
    protected Integer touchExtTimes;

    /**
     * 已获得奖励
     */
    protected Integer obtainedAwardInfo;

    /**
     * 额外信息
     */
    protected DrawExtInfoDTO extInfo;

    /**
     * 随机红包值
     */
    private Integer randomExposure;

    /**
     * 开场礼包开奖奖励范围
     */
    private List<Integer> exposureRatio;

    public List<Integer> getExposureRatio() {
        return exposureRatio;
    }

    public void setExposureRatio(List<Integer> exposureRatio) {
        this.exposureRatio = exposureRatio;
    }

    public Integer getRandomExposure() {
        return randomExposure;
    }

    public void setRandomExposure(Integer randomExposure) {
        this.randomExposure = randomExposure;
    }

    public Long getBaseUserId() {
        return baseUserId;
    }

    public void setBaseUserId(Long baseUserId) {
        this.baseUserId = baseUserId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getJoinTimes() {
        return joinTimes;
    }

    public void setJoinTimes(Integer joinTimes) {
        this.joinTimes = joinTimes;
    }

    public Integer getTouchExtTimes() {
        return touchExtTimes;
    }

    public void setTouchExtTimes(Integer touchExtTimes) {
        this.touchExtTimes = touchExtTimes;
    }

    public Integer getObtainedAwardInfo() {
        return obtainedAwardInfo;
    }

    public void setObtainedAwardInfo(Integer obtainedAwardInfo) {
        this.obtainedAwardInfo = obtainedAwardInfo;
    }

    public DrawExtInfoDTO getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(DrawExtInfoDTO extInfo) {
        this.extInfo = extInfo;
    }

}
